#ifndef __NLM__H
#define __NLM__H

#include <sys/types.h>

struct nlm_header
  {
    u_int8_t signature[24];	/* NetWare Loadable Module */
    u_int32_t version;		/* The version of the header (4)? */
    unsigned char module_name[14];	/* Upcase, DOS 8+3 w/ length & null */
    u_int32_t code_offset;	/* .text offset from start of file */
    u_int32_t code_size;	/* The size of the code image, in bytes. */
    u_int32_t data_offset;	/* .data offset from start of file */
    u_int32_t data_size;	/* The size of the data image, in bytes */
    u_int32_t uninitializedDataSize;

    /* The size of the uninitialized data region that the loader is to be
       allocated at load time.  Uninitialized data follows the initialized
       data in the NLM address space. */

    u_int32_t customDataOffset;

    /* The byte offset of the custom data from the start of the file.  The
       custom data is set by the CUSTOM keyword to NLMLINK.  It is possible
       for this to be EOF if there is no custom data. */

    u_int32_t customDataSize;
    /* The size of the custom data, in bytes. */

    u_int32_t modules_offset;
    u_int32_t modules_count;

    /* The number of module dependencies at the moduleDependencyOffset. */


    u_int32_t relocationFixupOffset;

    /* The byte offset of the relocation fixup data from the start of the file */

    u_int32_t numberOfRelocationFixups;

    u_int32_t externalReferencesOffset;

    u_int32_t numberOfExternalReferences;

    u_int32_t publicsOffset;

    u_int32_t numberOfPublics;
    u_int32_t debugInfoOffset;

    /* The byte offset of the internal debug info from the start of the file.
       It is possible for this to be EOF if there is no debug info. */

    u_int32_t numberOfDebugRecords;
    u_int32_t start_proc;
    u_int32_t terminate_proc;
    u_int32_t checkUnloadProcedureOffset;
    u_int32_t moduleType;
    u_int32_t flags;
  }
__attribute__ ((packed));

struct nlm_version_header
  {
    char signature[8];		/* VeRsIoN# */
    long majorVersion;
    long minorVersion;
    long revision;
    long year;
    long month;
    long day;
  };

#endif
